@@ -17,6 +17,7 @@
 #'     "A poor example deserves a C!"
 #' )))
 replace_grade <- function (x, grade_dt = lexicon::key_grade, ...) {
-    mgsub(x, grade_dt[["x"]], grade_dt[["y"]], fixed = FALSE)
+    
+    mgsub(x, paste0(' ', grade_dt[["x"]]), grade_dt[["y"]], fixed = TRUE, leadspace = TRUE)
 }
 
